@@ -107,7 +107,7 @@ class Download(Command):
             if invalid_file_types:
                 raise ValidationError(
                     f"Invalid file types: {', '.join(invalid_file_types)}. "
-                    f"Use gencove file-types command for list of valid file types. "
+                    f"Use gencove file-types command for a list of valid file types. "
                     f"Use with --project-id option to see project file types."
                 )
         except client.APIClientError as err:
@@ -142,6 +142,15 @@ class Download(Command):
         if self.download_urls:
             self.output_list()
 
+        if all(
+            [self.download_to != "-", not self.download_urls, not self.downloaded_files]
+        ):
+            sample_ids = [str(sample_id) for sample_id in self.sample_ids]
+            self.echo_warning(
+                f"Files not found for sample ids: {', '.join(sample_ids)} "
+                f"and file types: {', '.join(self.filters.file_types)}."
+            )
+
     @backoff.on_exception(
         backoff.expo,
         requests.exceptions.HTTPError,
@@ -149,7 +158,14 @@ class Download(Command):
         max_tries=10,
     )
     @backoff.on_exception(
-        backoff.expo, client.APIClientTooManyRequestsError, max_tries=20
+        backoff.expo,
+        client.APIClientTooManyRequestsError,
+        max_tries=20,
+    )
+    @backoff.on_exception(
+        backoff.expo,
+        client.APIClientTimeout,
+        max_tries=20,
     )
     def process_sample(self, sample_id):
         """Process sample.
@@ -164,7 +180,14 @@ class Download(Command):
             sample = self.api_client.get_sample_details(sample_id)
         except client.APIClientTooManyRequestsError:
             self.echo_debug(
-                f"Request was throttled for sample {sample_id}, trying again"
+                f"Request was throttled for sample {sample_id} "
+                "because of too many requests, trying again"
+            )
+            raise
+        except client.APIClientTimeout:
+            self.echo_debug(
+                f"Request was throttled for sample {sample_id} "
+                "because of timeout, trying again"
             )
             raise
         except client.APIClientError:
@@ -188,16 +211,6 @@ class Download(Command):
             self.echo_warning(f"Sample #{sample.id} has no deliverable.")
             return
 
-        sample_file_types = [file.file_type for file in sample.files]
-        file_types_set = set(self.filters.file_types)
-        sample_file_types_set = set(sample_file_types)
-        if not file_types_set.issubset(sample_file_types_set):
-            raise ValidationError(
-                f"Sample with id {sample.id} does not have any files with "
-                f"the following file types: "
-                f"{', '.join(list(file_types_set.difference(sample_file_types_set)))}"
-            )
-
         file_types_re = re.compile("|".join(self.filters.file_types), re.IGNORECASE)
 
         file_with_prefix = self.options.download_template.format(
