@@ -2,6 +2,7 @@
 # pylint: disable=E0012,C0330,R0913
 import click
 
+from .create.cli import create_project
 from .create_batch.cli import create_project_batch
 from .create_merged_vcf.cli import create_merged_vcf
 from .delete_samples.cli import delete_project_samples
@@ -11,6 +12,8 @@ from .import_existing_samples.cli import import_existing_project_samples
 from .list.cli import list_projects
 from .list_batch_types.cli import list_project_batch_types
 from .list_batches.cli import list_project_batches
+from .list_pipeline_capabilities.cli import list_project_pipeline_capabilities
+from .list_pipelines.cli import list_project_pipelines
 from .restore_samples.cli import restore_project_samples
 from .run_prefix.cli import run_prefix
 from .samples.cli import list_project_samples
@@ -22,11 +25,14 @@ def projects():
     """Project managements commands."""
 
 
+projects.add_command(create_project)
 projects.add_command(create_project_batch)
 projects.add_command(list_projects)
 projects.add_command(list_project_samples)
 projects.add_command(list_project_batch_types)
 projects.add_command(list_project_batches)
+projects.add_command(list_project_pipeline_capabilities)
+projects.add_command(list_project_pipelines)
 projects.add_command(get_batch)
 projects.add_command(delete_project_samples)
 projects.add_command(restore_project_samples)
