@@ -2,7 +2,8 @@
 import click
 
 from gencove.command.common_cli_options import add_options, common_options
-from gencove.constants import Credentials, SAMPLE_ASSIGNMENT_STATUS
+from gencove.constants import Credentials, SampleAssignmentStatus
+from gencove.utils import enum_as_dict
 
 from .constants import UploadsOptions
 from .main import ListSampleSheet
@@ -13,8 +14,8 @@ from .main import ListSampleSheet
 @click.option(
     "--status",
     help="Filter uploads by status of assignment",
-    type=click.Choice(SAMPLE_ASSIGNMENT_STATUS._asdict().values()),
-    default=SAMPLE_ASSIGNMENT_STATUS.all,
+    type=click.Choice(enum_as_dict(SampleAssignmentStatus).values()),
+    default=SampleAssignmentStatus.ALL.value,
 )
 @add_options(common_options)
 def list_uploads(  # pylint: disable=E0012,C0330,R0913
@@ -22,6 +23,6 @@ def list_uploads(  # pylint: disable=E0012,C0330,R0913
 ):
     """List user uploads."""
     ListSampleSheet(
-        Credentials(email, password, api_key),
-        UploadsOptions(host, status, search),
+        Credentials(email=email, password=password, api_key=api_key),
+        UploadsOptions(host=host, status=status, search=search),
     ).run()
