@@ -3,7 +3,7 @@ from datetime import datetime
 from typing import Any, List, Optional, Union
 from uuid import UUID
 
-from pydantic import BaseModel, HttpUrl
+from pydantic import BaseModel, HttpUrl, validator
 
 
 # pylint: disable=too-few-public-methods
@@ -62,8 +62,6 @@ class PipelineCapabilities(GencoveBaseModel):
     """Pipeline Capabilities record"""
 
     name: Optional[str]
-    private: Optional[bool]
-    merge_vcfs_enabled: Optional[bool]
 
 
 class SampleFile(GencoveBaseModel):
@@ -170,8 +168,18 @@ class QualityControlData(BaseModel):
 
     value_expected: Optional[float]
     value_measured: Optional[float]
+    value_string: Optional[str]
     status: Optional[str]
 
+    @validator("value_string", pre=True)
+    def blank_string(
+        cls, value: str  # noqa: N805
+    ):  # pylint: disable=no-self-argument,no-self-use
+        """Validator for value_string field, return None in case of empty string"""
+        if value == "":
+            return None
+        return value
+
 
 class QualityControl(BaseModel):
     """QualityControl model"""
@@ -347,3 +355,22 @@ class FileTypesModel(BaseModel):
 
     meta: ResponseMeta
     results: Optional[List[FileType]]
+
+
+class Pipeline(GencoveBaseModel):
+    """Pipeline model"""
+
+    version: str
+
+
+class PipelineDetail(Pipeline):
+    """Pipeline detail model"""
+
+    capabilities: List[PipelineCapabilities]
+
+
+class Pipelines(BaseModel):
+    """Pipeline model"""
+
+    meta: ResponseMeta
+    results: Optional[List[Pipeline]]
